summaryrefslogtreecommitdiffstats
path: root/job-cfg/chroot-installation.yaml.py
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2014-12-05 17:10:28 +0100
committerHolger Levsen <holger@layer-acht.org>2014-12-05 17:10:28 +0100
commite65af08961993685b4096f97610f4017aba103c1 (patch)
tree6675d6ba22ef3d932629504838414fd286d9e8e6 /job-cfg/chroot-installation.yaml.py
parent0c5a701d6c7ea790d0c87e0f65e091034ceedb5f (diff)
downloadjenkins.debian.net-e65af08961993685b4096f97610f4017aba103c1.tar.xz
chroot-installations: add two new target types: qt4 and qt5
Diffstat (limited to 'job-cfg/chroot-installation.yaml.py')
-rwxr-xr-xjob-cfg/chroot-installation.yaml.py14
1 files changed, 9 insertions, 5 deletions
diff --git a/job-cfg/chroot-installation.yaml.py b/job-cfg/chroot-installation.yaml.py
index 95916448..a6519dda 100755
--- a/job-cfg/chroot-installation.yaml.py
+++ b/job-cfg/chroot-installation.yaml.py
@@ -29,6 +29,8 @@ targets = """
lxde
xfce
full_desktop
+ qt4
+ qt5
haskell
developer
education-tasks
@@ -69,11 +71,11 @@ targets = """
def get_targets_in_distro(distro, targets):
targets_in_distro = []
for target in targets:
- # haskell, cinnamon and edu tests not in squeeze
- if distro == 'squeeze' and ( target == 'haskell' or target[:10] == 'education-' or target == 'cinnamon' ):
+ # haskell, cinnamon, qt5 and edu tests not in squeeze
+ if distro == 'squeeze' and ( target == 'haskell' or target[:10] == 'education-' or target == 'cinnamon' or target == 'qt5' ):
continue
- # education-desktop-mate and cinnamon weren't in wheezy
- if distro == 'wheezy' and ( target == 'education-desktop-mate' or target == 'cinnamon' ):
+ # qt5, education-desktop-mate and cinnamon weren't in wheezy
+ if distro == 'wheezy' and ( target == 'education-desktop-mate' or target == 'cinnamon' or target == 'qt5' ):
continue
targets_in_distro.append(target)
return targets_in_distro
@@ -88,7 +90,7 @@ def get_recipients(target):
return 'jenkins+debian-haskell holger@layer-acht.org pkg-haskell-maintainers@lists.alioth.debian.org'
elif target == 'cinnamon':
return 'jenkins+debian-cinnamon pkg-cinnamon-team@lists.alioth.debian.org holger@layer-acht.org'
- elif target[:3] == 'kde':
+ elif target[:3] == 'kde' or target[:2] == 'qt':
return 'jenkins+debian-qa debian-qt-kde@lists.debian.org holger@layer-acht.org'
elif target[:10] == 'education-':
return 'jenkins+debian-edu debian-edu-commits@lists.alioth.debian.org'
@@ -121,6 +123,8 @@ spoken_names = { 'gnome': 'GNOME',
'cinnamon': 'Cinnamon',
'lxde': 'LXDE',
'xfce': 'Xfce',
+ 'qt4': 'Qt4 cross-platform C++ application framework',
+ 'qt5': 'Qt5 cross-platform C++ application framework',
'full_desktop': 'four desktop environments and the most commonly used applications and packages',
'haskell': 'all Haskell related packages',
'developer': 'four desktop environments and the most commonly used applications and packages - and the build depends for all of these' }